@@ -10,8 +10,8 @@ killall dhclient dhclient3 2>/dev/null
 # managed by other tools, such as NetworkManager, and will be brought up
 # automatically). Due to logical interfaces, the interfaces that we pass to
 # ifdown are DIFFERENT than those that we pass to ifup, see Debian BTS #475002.
-IFDOWN_INTERFACES="`cat /etc/network/run/ifstate | sed 's/=.*//'`"
-IFUP_INTERFACES="`cat /etc/network/run/ifstate`"
+IFDOWN_INTERFACES="`cat /var/run/network/ifstate | sed 's/=.*//'`"
+IFUP_INTERFACES="`cat /var/run/network/ifstate`"
 
 must_control_interface()
 {
@@ -28,18 +28,11 @@ must_control_interface()
 # Shut down the interfaces (except lo, which can and should be kept up)
 for x in $IFDOWN_INTERFACES; do
     if must_control_interface $x ; then
- 	if [ -x /sbin/wpa_action ] && wpa_action $x check; then
-	 	# Ugly workaround for the fact that wpasupplicant does not hook
-	 	# into ifdown itself. See Debian BTS #473184, #390884.
- 		wpa_action $x stop
- 	else
- 		ifdown $x
- 	fi
+        ifdown $x
     fi
 done
 
-# Tell NetworkManager to shut down networking
-dbus-send --system --dest=org.freedesktop.NetworkManager /org/freedesktop/NetworkManager org.freedesktop.NetworkManager.sleep
+# TODO:  Tell NetworkManager to shut down networking at this point
 
 # Find the remaining running network interfaces...
 INTERFACES=`/sbin/ifconfig | awk '/^[^ ]+/ {print $1}'`
