@@ -1,6 +1,6 @@
 #!/bin/sh
 
-[ -f /usr/share/acpi-support/key-constants ] || exit 0
+test -f /usr/share/acpi-support/key-constants || exit 0
 
 # Find and toggle wireless device states
 
